<?php 
/**
 * Loading theme related files
 *
 * @since Simple 3.0
 */
require get_theme_file_path( 'inc/meta-box.php' );
require get_theme_file_path( 'inc/postviews.php' );
require get_theme_file_path( 'inc/share-meta-box.php' );
require get_theme_file_path( 'inc/admin/setting.php' );
require get_theme_file_path( 'inc/admin/setting-config.php' );
/**
 * scripts_styles
 *
 * @since Simple 3.0
 */
function zb_scripts_styles() {

	$version = wp_get_theme()->Version;
	wp_enqueue_style( 'bootstrap', '//cdn.bootcss.com/bootstrap/3.3.6/css/bootstrap.min.css', array(), $version);
	wp_enqueue_style( 'font-awesome', '//cdn.bootcss.com/font-awesome/4.6.3/css/font-awesome.min.css', array(), $version);
	wp_enqueue_style( 'style', get_stylesheet_uri() );

	// Register jQuery
	wp_enqueue_script( 'jquery-s', '//cdn.bootcss.com/jquery/2.1.1/jquery.min.js' );
	wp_enqueue_script( 'toTop', get_template_directory_uri() . '/js/jquery.toTop.min.js', array( 'jquery-s' ), $version , true );
	wp_enqueue_script( 'menu', get_template_directory_uri() . '/js/menu.js', array( 'jquery-s' ), $version , true );

}
add_action( 'wp_enqueue_scripts', 'zb_scripts_styles' );
/**
 * Js & Css TO ADMIN
 *
 * @since Simple 3.0
 */
add_action( 'admin_enqueue_scripts', 'barley_setting_scripts' );
function barley_setting_scripts(){
    global $pagenow;
	$version = wp_get_theme()->Version;
    if( $pagenow == "admin.php"){
		wp_enqueue_media();
        wp_enqueue_style('setting',  get_template_directory_uri() . '/inc/admin/css/seting.css', false, $version, false);
        wp_enqueue_script('setting', get_template_directory_uri() .'/inc/admin/js/setting.js' , array('jquery') , $version,true);
    }

}
/**
 * theme setup
 *
 * @since Simple 3.0
 */
function simple_setup() {
    register_nav_menu( 'simple', __( '菜单 Primary Menu', 'simple' ) );
    add_theme_support( 'post-thumbnails' );
    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );
    add_filter( 'pre_option_link_manager_enabled', '__return_true' );
    add_theme_support( 'post-formats', array(
        'status',
    ) );
}
add_action( 'after_setup_theme', 'simple_setup' );
/**
 * link_items
 *
 * @since Simple 3.0
 */
function get_the_link_items($id = null){
    $bookmarks = get_bookmarks('orderby=date&category=' .$id );
    $output = '';
    if ( !empty($bookmarks) ) {
        $output .= '';
        foreach ($bookmarks as $bookmark) {
            $output .=  '<li><a href="' . $bookmark->link_url . '" title="' . $bookmark->link_description . '" target="_blank" >'. $bookmark->link_name .'</a></li>';
        }
        $output .= '';
    }
    return $output;
}
/**
 * get_link_items
 *
 * @since Barley 1.0
 */
function get_link_items(){
    $linkcats = get_terms( 'link_category' );
    if ( !empty($linkcats) ) {
        foreach( $linkcats as $linkcat){            
            $result .=  ''.$linkcat->name.'';
            if( $linkcat->description ) $result .= '<div class="link-description">' . $linkcat->description . '</div>';
            $result .=  get_the_link_items($linkcat->term_id);
        }
    } else {
        $result = get_the_link_items();
    }
    return $result;
}

function shortcode_link(){
    return get_link_items();
}
add_shortcode('bigfalink', 'shortcode_link');
/**
 * post_thumbnail
 *
 * @since Simple 3.0
 */
function zb_get_background_image($post_id,$width = null,$height = null){
    if( has_post_thumbnail($post_id) ){
        $timthumb_src = wp_get_attachment_image_src(get_post_thumbnail_id($post_id),'full');
        $output = $timthumb_src[0];
    } else {
        $content = get_post_field('post_content', $post_id);
        $defaltthubmnail = 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==';
        preg_match_all('/<img.*?(?: |\\t|\\r|\\n)?src=[\'"]?(.+?)[\'"]?(?:(?: |\\t|\\r|\\n)+.*?)?>/sim', $content, $strResult, PREG_PATTERN_ORDER);
        $n = count($strResult[1]);
        if($n > 0){
            $output = $strResult[1][0];
        } else {
            $output = $defaltthubmnail;
        }
    }
    if ( $height && $width ) {
        $result = get_template_directory_uri() . "/timthumb.php&#63;src={$output}&#38;w={$width}&#38;h={$height}&#38;zc=1&#38;q=100";
    } else {
        $result = $output;
    }
    return $result;
}
/**
 * pc & mobile qq link
 *
 * @since Simple 3.0
 */
function social_link(){
	$qq = barley_get_setting('social-qq');
	if ( wp_is_mobile() ) {
	    $output .= 'mqqwpa://im/chat?chat_type=wpa&uin='.$qq.'&version=1&src_type=web&web_src='.home_url().'';
	}else{
		$output .= 'tencent://AddContact/?fromId=45&fromSubId=1&subcmd=all&uin='.$qq.'';
	}
	return $output;
}
/**
 * menu
 *
 * @since Simple 3.0
 */
function link_to_menu_editor( $args ){
    if ( ! current_user_can( 'manage_options' ) ){
        return;
    }
    extract( $args );
    $link = $link_before
        . '<a href="' .admin_url( 'nav-menus.php' ) . '">' . $before . 'Add a menu 添加菜单' . $after . '</a>'
        . $link_after;
    if ( FALSE !== stripos( $items_wrap, '<ul' )
        or FALSE !== stripos( $items_wrap, '<ol' )
    )
    {
        $link = "<li>$link</li>";
    }
    $output = sprintf( $items_wrap, $menu_id, $menu_class, $link );
    if ( ! empty ( $container ) )
    {
        $output  = "<$container class='$container_class' id='$container_id'>$output</$container>";
    }
    if ( $echo )
    {
        echo $output;
    }
    return $output;
}
/**
 * home paging
 *
 * @since Simple 3.0
 */
function paging_nav() {
	global $wp_query;
	$pages = $wp_query->max_num_pages;
	if ( $pages >= 2 ):
	$big = 999999999;
	$paginate = paginate_links( array(
		'base'		=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format'	=> '?paged=%#%',
		'current'	=> max( 1, get_query_var('paged') ),
		'total'		=> $wp_query->max_num_pages,
		'end_size'	=> 13,
		'type'		=> 'array'
	) );
	echo '<ul class="pagination">';
	foreach ($paginate as $value) {
	echo '<li>'.$value.'</li>';
	}
	echo '</ul>';
	endif;
}
/**
 * add down&demo to content
 *
 * @since Simple 3.0
 */ 
function down_show_down($content) {
	if(is_single()){
		$down_start=get_post_meta(get_the_ID(), 'down_start', true);
		$down_url=get_post_meta(get_the_ID(), 'down_url', true);
		$down_demo=get_post_meta(get_the_ID(), 'down_demo', true);
		if($down_url){
		$demo_content = '<a href="'.$down_demo.'" target="_blank"><i class="fa fa-external-link"></i>预览地址</a>';
		}
		if($down_start){
			$content .= '';
			$content .= '<div class="downBox"><ul class="downul clearfix"><li><a href="'.$down_url.'" target="_blank"><i class="fa fa-download"></i>下载地址</a></li><li class="middleli">'.$demo_content.'</li><li><a href="'.get_bloginfo('url').'"><i class="fa fa-home"></i>返回首页</a></li></ul></div>';
		}
	}
	return $content;
}
add_action('the_content','down_show_down');
/**
 * avatar
 *
 * @since Simple 3.0
 */ 
add_filter( 'avatar_defaults', 'newgravatar' );
function newgravatar ($avatar_defaults) {
    $myavatar = get_bloginfo('template_directory') . '/images/kide.jpg';
    $avatar_defaults[$myavatar] = "自定义头像";
    return $avatar_defaults;
}
function get_ssl_avatar($avatar) {
    $avatar = str_replace(array("www.gravatar.com", "0.gravatar.com", "1.gravatar.com", "2.gravatar.com"), "cn.gravatar.com", $avatar);
    return $avatar;
}
add_filter('get_avatar', 'get_ssl_avatar');
/**
 * post_views
 *
 * @since Simple 3.0
 */ 
function custom_the_views($post_id, $echo=true, $views='') {
    $count_key = 'views';  
    $count = get_post_meta($post_id, $count_key, true);  
    if ($count == '') {  
        delete_post_meta($post_id, $count_key);  
        add_post_meta($post_id, $count_key, '0');  
        $count = '0';  
    }  
    if ($echo)  
        echo number_format_i18n($count) . $views;  
    else  
        return number_format_i18n($count) . $views;  
}  
function set_post_views() {  
    global $post;  
    $post_id = $post->ID;  
    $count_key = 'views';  
    $count = get_post_meta($post_id, $count_key, true);  
    if (is_single() || is_page()) {  
        if ($count == '') {  
            delete_post_meta($post_id, $count_key);  
            add_post_meta($post_id, $count_key, '0');  
        } else {  
            update_post_meta($post_id, $count_key, $count + 1);  
        }  
    }  
}  
add_action('get_header', 'set_post_views'); 
/**
 * custom admin login
 *
 * @since Simple 3.0
 */ 
function custom_login() {   
	echo '<link rel="shortcut icon"  href="' . get_bloginfo('template_directory') . '/images/favicon.png" />';
	echo '<link rel="stylesheet" tyssspe="text/css" href="' . get_bloginfo('template_directory') . '/css/login.css" />'; 
	echo '<script src="' . get_bloginfo('template_directory') . '/js/login.js"></script>'; 
}   
add_action('login_head', 'custom_login');
/**
 * only search title
 *
 * @since Simple 3.0
 */
function search_by_title_only( $search, &$wp_query ){
    global $wpdb;
    if ( empty( $search ) )
        return $search; 
    $q = $wp_query->query_vars;    
    $n = ! empty( $q['exact'] ) ? '' : '%';
 
    $search =
    $searchand = '';
    foreach ( (array) $q['search_terms'] as $term ) {
        $term = esc_sql( like_escape( $term ) );
        $search .= "{$searchand}($wpdb->posts.post_title LIKE '{$n}{$term}{$n}')";
        $searchand = ' AND ';
    }
    if ( ! empty( $search ) ) {
        $search = " AND ({$search}) ";
        if ( ! is_user_logged_in() )
            $search .= " AND ($wpdb->posts.post_password = '') ";
    }
    return $search;
}
add_filter( 'posts_search', 'search_by_title_only', 500, 2 );
/**
 * Smtp mail
 *
 * @since Simple 3.0
 */
function mail_smtp( $phpmailer ) {
  $phpmailer->IsSMTP();
  $phpmailer->FromName = ''.barley_get_setting('smtp-name').''; 
  $phpmailer->SMTPAuth = true;
  $phpmailer->Port = 465;
  $phpmailer->SMTPSecure ="ssl";
  $phpmailer->Host = ''.barley_get_setting('smtp-host').'';
  $phpmailer->Username = ''.barley_get_setting('smtp-account').'';
  $phpmailer->Password =''.barley_get_setting('smtp-pass').'';
}
add_action('phpmailer_init', 'mail_smtp');
function barley_wp_mail_from( $original_email_address ) {
    return ''.barley_get_setting('smtp-account').'';
}
add_filter( 'wp_mail_from', 'barley_wp_mail_from' );
/**
 * add_checkbox
 *
 * @since Simple 3.0
 */
add_action('comment_form', 'lb_comment_add_checkbox');
function lb_comment_add_checkbox() {
	echo '<label for="comment_mail_notify" class="checkbox inline hide" style="padding-top:0"><input type="checkbox" name="comment_mail_notify" id="comment_mail_notify" value="comment_mail_notify" checked="checked"/>有人回复时邮件通知我</label>';
}
/**
 * comment list
 *
 * @since Simple 3.0
 */
function simple_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li class="comment" id="comment-<?php comment_ID(); ?>">
   		<div class="media">
   			<div class="media-left">
        		<?php if (function_exists('get_avatar') && get_option('show_avatars')) { echo get_avatar($comment, 48); } ?>
   			</div>
   			<div class="media-body">
   				<?php printf(__('<p class="author_name">%s</p>'), get_comment_author_link()); ?>
		        <?php if ($comment->comment_approved == '0') : ?>
		            <em>评论等待审核...</em><br />
				<?php endif; ?>
				<?php comment_text(); ?>
   			</div>
   		</div>
   		<div class="comment-metadata">
   			<span class="comment-pub-time">
   				<?php echo get_comment_time('Y-m-d H:i'); ?>
   			</span>
   			<span class="comment-btn-reply">
 				<i class="fa fa-reply"></i> <?php comment_reply_link(array_merge( $args, array('reply_text' => '回复','depth' => $depth, 'max_depth' => $args['max_depth']))) ?> 
   			</span>
   		</div>

<?php
}
/**
 * remove_action
 *
 * @since Simple 3.0
 */
remove_action( 'wp_head',   'rsd_link' ); 
remove_action( 'wp_head',   'wlwmanifest_link' ); 
remove_action( 'wp_head',   'index_rel_link' ); 
remove_action( 'wp_head',   'start_post_rel_link', 10, 0 ); 
remove_action( 'wp_head',   'wp_generator' ); 
remove_action( 'wp_head',   'wp_resource_hints', 2 );
remove_action( 'wp_head',   'feed_links', 2 );
remove_action( 'wp_head',   'feed_links_extra', 3);
remove_action( 'wp_head',   'wp_shortlink_wp_head' );
remove_action( 'wp_head',   'parent_post_rel_link', 10, 0);
remove_action( 'wp_head',   'adjacent_posts_rel_link', 10, 0);
remove_filter( 'the_content', 'wptexturize');
add_filter('show_admin_bar', '__return_false');
add_filter( 'wp_revisions_to_keep', 'specs_wp_revisions_to_keep', 10, 2 );
add_filter('comment_form_field_cookies','__return_false');
add_filter( 'add_image_size', create_function( '', 'return 1;' ) );
function specs_wp_revisions_to_keep( $num, $post ) {
    return 0;
}
function remove_open_sans() {
wp_deregister_style( 'open-sans' );
wp_register_style( 'open-sans', false );
wp_enqueue_style('open-sans', '');
}
add_action( 'init', 'remove_open_sans' );
function disable_emojis() {
    remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
    remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
    remove_action( 'wp_print_styles', 'print_emoji_styles' );
    remove_action( 'admin_print_styles', 'print_emoji_styles' );    
    remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
    remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );  
    remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
    add_filter( 'tiny_mce_plugins', 'disable_emojis_tinymce' );
	add_filter( 'widget_text', 'do_shortcode' );
}
add_action( 'init', 'disable_emojis' );
function disable_emojis_tinymce( $plugins ) {
    return array_diff( $plugins, array( 'wpemoji' ) );
}
function convert_pre_entities( $matches ) {
    return str_replace( $matches[1], htmlentities( $matches[1] ), $matches[0] );
}
add_filter('page_css_class', 'my_css_attributes_filter', 100, 1);
function my_css_attributes_filter($var) {
	return is_array($var) ? array() : '';
}
function example_remove_dashboard_widgets() {
    global $wp_meta_boxes;
    unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_recent_drafts']);
    unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_primary']);
    unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_secondary']);
    unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_right_now']);
}
add_action('wp_dashboard_setup', 'example_remove_dashboard_widgets' );
?>